## Правовая информация

Проект **Kokao Engine** является независимой реализацией метода функционально-независимых структур, описанного в книге Ю.Б. Косякова (1999). Авторы проекта не связаны с правообладателями указанной работы.

Согласно открытым данным, патент РФ №2109332 «Способ распознавания образов» утратил силу в 2018 году. Таким образом, математический метод находится в общественном достоянии.

Код распространяется под лицензией Apache 2.0 и предоставляется «как есть», без каких-либо гарантий. Авторы не несут ответственности за возможный ущерб, связанный с использованием данного программного обеспечения.
